MachineProfile

Enum MachineProfile 

pub enum MachineProfile {
    Nano,
    Micro,
    Small,
    Medium,
    Large,
    XLarge,
    XXLarge,
}
Predefined instance profiles with fixed vCPU and RAM. They only exist to provide convenient default values — the actual network tuning is derived from the resolved ram_mb and cpu_cores.

ProfilevCPURAM
Nano2512 MB
Micro21 GB
Small22 GB
Medium24 GB
Large28 GB
XLarge416 GB
XXLarge832 GB

Variants



Nano

2 vCPU, 512 MB RAM.



Micro

2 vCPU, 1 GB RAM.



Small

2 vCPU, 2 GB RAM.



Medium

2 vCPU, 4 GB RAM.



Large

2 vCPU, 8 GB RAM.



XLarge

4 vCPU, 16 GB RAM.



XXLarge

8 vCPU, 32 GB RAM.

Implementations

Source

impl MachineProfile

pub const fn ram_mb(self) -> u64

Canonical RAM for this profile in megabytes.

pub const fn cpu_cores(self) -> usize

vCPU count for this profile.