pub struct NetworkWorker<T>{ /* private fields */ }Expand description
Main network worker. Must be polled in order for the network to advance.
The worker is responsible for handling the network events and commands.
Implementations
Sourceimpl<T: Debug + Serialize> NetworkWorker<T>
impl<T: Debug + Serialize> NetworkWorker<T>
Sourcepub fn new(
keys: &KeyPair,
config: Config,
monitor: Option<ActorRef<Monitor>>,
graceful_token: CancellationToken,
crash_token: CancellationToken,
machine_spec: Option<MachineSpec>,
metrics: Option<Arc<NetworkMetrics>>,
) -> Result<Self, Error>
pub fn new( keys: &KeyPair, config: Config, monitor: Option<ActorRef<Monitor>>, graceful_token: CancellationToken, crash_token: CancellationToken, machine_spec: Option<MachineSpec>, metrics: Option<Arc<NetworkMetrics>>, ) -> Result<Self, Error>
Create a new NetworkWorker.
Sourcepub fn add_helper_sender(&mut self, helper_sender: Sender<CommandHelper<T>>)
pub fn add_helper_sender(&mut self, helper_sender: Sender<CommandHelper<T>>)
Add sender helper
Sourcepub const fn local_peer_id(&self) -> PeerId
pub const fn local_peer_id(&self) -> PeerId
Get the local peer ID.
Sourcepub fn service(&self) -> NetworkService
pub fn service(&self) -> NetworkService
Get the network service.
Sourcepub async fn run_connection(&mut self) -> Result<(), Error>
pub async fn run_connection(&mut self) -> Result<(), Error>
Run connection to bootstrap node.