pub struct RoutingConfig { /* private fields */ }Expand description
Configuration for the routing behaviour.
Implementations
Sourceimpl Config
impl Config
Sourcepub const fn get_dht_random_walk(&self) -> bool
pub const fn get_dht_random_walk(&self) -> bool
Get DHT random walk.
Sourcepub const fn with_dht_random_walk(self, enable: bool) -> Self
pub const fn with_dht_random_walk(self, enable: bool) -> Self
Enables or disables random walks in the Kademlia DHT.
Sourcepub const fn get_discovery_limit(&self) -> u64
pub const fn get_discovery_limit(&self) -> u64
Get discovery limits.
Sourcepub const fn with_discovery_limit(self, num: u64) -> Self
pub const fn with_discovery_limit(self, num: u64) -> Self
Sets the number of active connections over which we interrupt the discovery process.
Sourcepub const fn get_allow_private_address_in_dht(&self) -> bool
pub const fn get_allow_private_address_in_dht(&self) -> bool
Get allow_local_address_in_dht.
Sourcepub const fn with_allow_private_address_in_dht(self, allow: bool) -> Self
pub const fn with_allow_private_address_in_dht(self, allow: bool) -> Self
Whether to allow local addresses in the DHT.
Sourcepub const fn get_allow_dns_address_in_dht(&self) -> bool
pub const fn get_allow_dns_address_in_dht(&self) -> bool
Get allow_dns_address_in_dht.
Sourcepub const fn with_allow_dns_address_in_dht(self, allow: bool) -> Self
pub const fn with_allow_dns_address_in_dht(self, allow: bool) -> Self
Whether to allow non-global addresses in the DHT.
Sourcepub const fn get_allow_loop_back_address_in_dht(&self) -> bool
pub const fn get_allow_loop_back_address_in_dht(&self) -> bool
Get allow_non_globals_in_dht.
Sourcepub const fn with_allow_loop_back_address_in_dht(self, allow: bool) -> Self
pub const fn with_allow_loop_back_address_in_dht(self, allow: bool) -> Self
Whether to allow non-global addresses in the DHT.
Sourcepub const fn get_kademlia_disjoint_query_paths(&self) -> bool
pub const fn get_kademlia_disjoint_query_paths(&self) -> bool
Get allow kademlia disjoint query paths
Sourcepub const fn with_kademlia_disjoint_query_paths(self, enable: bool) -> Self
pub const fn with_kademlia_disjoint_query_paths(self, enable: bool) -> Self
When enabled the number of disjoint paths used equals the configured parallelism.